/*
   Controls a JTD-0801 HDMI Swith/UpScaler via Arduino by sending the approriate IR command via an IR blaster. Requires an IR reciever connected to the JTD box.
   Commands are sent via the Serial monitor.
*/

#include <Arduino.h>                            // Arduino Library. Just needed to run
#define DISABLE_CODE_FOR_RECEIVER               // Disables restarting receiver after each send. Saves some memory & ram on Arduino. Not required but nice. 
#define IR_SEND_PIN   3                         // Sets the pin the IR blaster is connected to. Must be a PWM pin. 
#include <IRremote.hpp>                         // Includes Remote library

byte serialRead;                                // Variable to hold input from serial monitor


void setup() {
  Serial.begin(9600);                             // Starts serial monitor
  Serial.println("Waiting for commands...");      // Nice for formatting
  IrSender.begin();                               // Starts/Enables the IR blaster
}

void loop() {
  if (Serial.available()) {                       // If serial is avalaible...
    serialRead = Serial.read();                   // Reads the command recieved from the serial port & stroes it as serialRead
    IRSwitcher();                                 // Method that reads serial input and sends out the correct IR command
  }
}

void IRSwitcher() {                                   // Method that reads serial input and sends out the correct IR command
  switch (serialRead)                                 // A switch statment that checks the data recieved from serial and figures out what IR command to send
  {
    case '0':                                         // If a "0" is sent via the serial monitor...
      IrSender.sendNEC(0x80, 0x07, 1);                // Sends the command to switch input to VGA
      delay(40);                                      // Little delay to help with repeats & ghost readings
      Serial.println("VGA Sent.");                    // Prints out what IR code was sent to the serial monitor
      break;
    case '1':
      IrSender.sendNEC(0x80, 0x09, 1);
      delay(40);
      Serial.println("HDMI 1 Sent.");
      break;
    case '2':
      IrSender.sendNEC(0x80, 0x0A, 1);
      delay(40);
      Serial.println("HDMI 2 Sent.");
      break;
    case '3':
      IrSender.sendNEC(0x80, 0x1F, 1);
      delay(40);
      Serial.println("HDMI 3 Sent.");
      break;
    case '4':
      IrSender.sendNEC(0x80, 0x03, 1);
      delay(40);
      Serial.println("AV 2 Sent.");
      break;
    case '5':
      IrSender.sendNEC(0x80, 0x01, 1);
      delay(40);
      Serial.println("AV 1 Sent.");
      break;
    case '6':
      IrSender.sendNEC(0x80, 0x06, 1);
      delay(40);
      Serial.println("Component 1 Sent.");
      break;
    case '7':
      IrSender.sendNEC(0x80, 0x04, 1);
      delay(40);
      Serial.println("Component 2 Sent.");
      break;
    case 's':
      IrSender.sendNEC(0x80, 0x1A, 1);
      delay(40);
      Serial.println("Standby Sent.");
      break;
    default:
      // No defaults so left blank
      break;
  }
}
